@@ -12,7 +12,7 @@ from gql.transport.exceptions import TransportQueryError
 import httpx
 
 from ..core.adapter import BaseAdapter
-from ..core.models import Epic, Task, Comment, SearchQuery, TicketState, Priority
+from ..core.models import Epic, Task, Comment, SearchQuery, TicketState, Priority, TicketType
 from ..core.registry import AdapterRegistry
 
 
@@ -277,8 +277,11 @@ class LinearAdapter(BaseAdapter[Task]):
             config: Configuration with:
                 - api_key: Linear API key (or LINEAR_API_KEY env var)
                 - workspace: Linear workspace name (optional, for documentation)
-                - team_key: Linear team key (required, e.g., 'BTA')
+                - team_key: Linear team key (e.g., 'BTA') OR
+                - team_id: Linear team UUID (e.g., '02d15669-7351-4451-9719-807576c16049')
                 - api_url: Optional Linear API URL
+
+        Note: Either team_key or team_id is required. If both are provided, team_id takes precedence.
         """
         super().__init__(config)
 
@@ -288,18 +291,16 @@ class LinearAdapter(BaseAdapter[Task]):
             raise ValueError("Linear API key required (config.api_key or LINEAR_API_KEY env var)")
 
         self.workspace = config.get("workspace")  # Optional, for documentation
-        self.team_key = config.get("team_key")
-        if not self.team_key:
-            raise ValueError("Linear team_key is required in configuration")
-        self.api_url = config.get("api_url", "https://api.linear.app/graphql")
 
-        # Setup GraphQL client with authentication
-        transport = HTTPXAsyncTransport(
-            url=self.api_url,
-            headers={"Authorization": self.api_key},
-            timeout=30.0,
-        )
-        self.client = Client(transport=transport, fetch_schema_from_transport=False)
+        # Support both team_key (short key) and team_id (UUID)
+        self.team_key = config.get("team_key")  # Short key like "BTA"
+        self.team_id_config = config.get("team_id")  # UUID like "02d15669-..."
+
+        # Require at least one team identifier
+        if not self.team_key and not self.team_id_config:
+            raise ValueError("Either team_key or team_id is required in configuration")
+
+        self.api_url = config.get("api_url", "https://api.linear.app/graphql")
 
         # Caches for frequently used data
         self._team_id: Optional[str] = None
@@ -314,6 +315,22 @@ class LinearAdapter(BaseAdapter[Task]):
         self._init_lock = asyncio.Lock()
         self._initialized = False
 
+    def _create_client(self) -> Client:
+        """Create a fresh GraphQL client for each operation.
+
+        This prevents 'Transport is already connected' errors by ensuring
+        each operation gets its own client and transport instance.
+
+        Returns:
+            Client: Fresh GraphQL client instance
+        """
+        transport = HTTPXAsyncTransport(
+            url=self.api_url,
+            headers={"Authorization": self.api_key},
+            timeout=30.0,
+        )
+        return Client(transport=transport, fetch_schema_from_transport=False)
+
     async def initialize(self) -> None:
         """Initialize adapter by preloading team, states, and labels data concurrently."""
         if self._initialized:
@@ -347,9 +364,36 @@ class LinearAdapter(BaseAdapter[Task]):
                 raise e
 
     async def _fetch_team_data(self) -> str:
-        """Fetch team ID."""
+        """Fetch team ID.
+
+        If team_id is configured, validate it exists and return it.
+        If team_key is configured, fetch the team_id by key.
+        """
+        # If team_id (UUID) is provided, use it directly (preferred)
+        if self.team_id_config:
+            # Validate that this team ID exists
+            query = gql("""
+                query GetTeamById($id: String!) {
+                    team(id: $id) {
+                        id
+                        name
+                        key
+                    }
+                }
+            """)
+
+            client = self._create_client()
+            async with client as session:
+                result = await session.execute(query, variable_values={"id": self.team_id_config})
+
+            if not result.get("team"):
+                raise ValueError(f"Team with ID '{self.team_id_config}' not found")
+
+            return result["team"]["id"]
+
+        # Otherwise, fetch team ID by key
         query = gql("""
-            query GetTeam($key: String!) {
+            query GetTeamByKey($key: String!) {
                 teams(filter: { key: { eq: $key } }) {
                     nodes {
                         id
@@ -360,7 +404,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(query, variable_values={"key": self.team_key})
 
         if not result["teams"]["nodes"]:
@@ -384,7 +429,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(query, variable_values={"teamId": team_id})
 
         workflow_states = {}
@@ -410,7 +456,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(query, variable_values={"teamId": team_id})
 
         return {label["name"]: label["id"] for label in result["issueLabels"]["nodes"]}
@@ -451,7 +498,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 search_query,
                 variable_values={"name": name, "teamId": team_id}
@@ -481,7 +529,8 @@ class LinearAdapter(BaseAdapter[Task]):
         if color:
             label_input["color"] = color
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 create_query,
                 variable_values={"input": label_input}
@@ -510,7 +559,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(query, variable_values={"email": email})
 
         if result["users"]["nodes"]:
@@ -520,6 +570,18 @@ class LinearAdapter(BaseAdapter[Task]):
 
         return None
 
+    def validate_credentials(self) -> tuple[bool, str]:
+        """Validate that required credentials are present.
+
+        Returns:
+            (is_valid, error_message) - Tuple of validation result and error message
+        """
+        if not self.api_key:
+            return False, "LINEAR_API_KEY is required but not found. Set it in .env.local or environment."
+        if not self.team_key and not self.team_id_config:
+            return False, "Either Linear team_key or team_id is required in configuration. Set it in .mcp-ticketer/config.json"
+        return True, ""
+
     def _get_state_mapping(self) -> Dict[TicketState, str]:
         """Get mapping from universal states to Linear state types.
 
@@ -629,6 +691,20 @@ class LinearAdapter(BaseAdapter[Task]):
             child_ids = [child["identifier"] for child in issue["children"]["nodes"]]
             metadata["linear"]["child_issues"] = child_ids
 
+        # Determine ticket type based on parent relationships
+        ticket_type = TicketType.ISSUE
+        parent_issue_id = None
+        parent_epic_id = None
+
+        if issue.get("parent"):
+            # Has a parent issue, so this is a sub-task
+            ticket_type = TicketType.TASK
+            parent_issue_id = issue["parent"]["identifier"]
+        elif issue.get("project"):
+            # Has a project but no parent, so it's a standard issue under an epic
+            ticket_type = TicketType.ISSUE
+            parent_epic_id = issue["project"]["id"]
+
         return Task(
             id=issue["identifier"],
             title=issue["title"],
@@ -636,9 +712,11 @@ class LinearAdapter(BaseAdapter[Task]):
             state=state,
             priority=priority,
             tags=tags,
-            parent_issue=issue.get("parent", {}).get("identifier") if issue.get("parent") else None,
-            parent_epic=issue.get("project", {}).get("id") if issue.get("project") else None,
+            ticket_type=ticket_type,
+            parent_issue=parent_issue_id,
+            parent_epic=parent_epic_id,
             assignee=issue.get("assignee", {}).get("email") if issue.get("assignee") else None,
+            children=child_ids,
             estimated_hours=issue.get("estimate"),
             created_at=datetime.fromisoformat(issue["createdAt"].replace("Z", "+00:00"))
             if issue.get("createdAt") else None,
@@ -647,8 +725,59 @@ class LinearAdapter(BaseAdapter[Task]):
             metadata=metadata,
         )
 
+    def _epic_from_linear_project(self, project: Dict[str, Any]) -> Epic:
+        """Convert Linear project to universal Epic."""
+        # Map project state to ticket state
+        project_state = project.get("state", "planned").lower()
+        state_mapping = {
+            "planned": TicketState.OPEN,
+            "started": TicketState.IN_PROGRESS,
+            "paused": TicketState.WAITING,
+            "completed": TicketState.DONE,
+            "canceled": TicketState.CLOSED,
+        }
+        state = state_mapping.get(project_state, TicketState.OPEN)
+
+        # Extract teams
+        teams = []
+        if project.get("teams") and project["teams"].get("nodes"):
+            teams = [team["name"] for team in project["teams"]["nodes"]]
+
+        metadata = {
+            "linear": {
+                "id": project["id"],
+                "state": project.get("state"),
+                "url": project.get("url"),
+                "icon": project.get("icon"),
+                "color": project.get("color"),
+                "target_date": project.get("targetDate"),
+                "started_at": project.get("startedAt"),
+                "completed_at": project.get("completedAt"),
+                "teams": teams,
+            }
+        }
+
+        return Epic(
+            id=project["id"],
+            title=project["name"],
+            description=project.get("description"),
+            state=state,
+            ticket_type=TicketType.EPIC,
+            tags=[f"team:{team}" for team in teams],
+            created_at=datetime.fromisoformat(project["createdAt"].replace("Z", "+00:00"))
+            if project.get("createdAt") else None,
+            updated_at=datetime.fromisoformat(project["updatedAt"].replace("Z", "+00:00"))
+            if project.get("updatedAt") else None,
+            metadata=metadata,
+        )
+
     async def create(self, ticket: Task) -> Task:
         """Create a new Linear issue with full field support."""
+        # Validate credentials before attempting operation
+        is_valid, error_message = self.validate_credentials()
+        if not is_valid:
+            raise ValueError(error_message)
+
         team_id = await self._ensure_team_id()
         states = await self._get_workflow_states()
 
@@ -713,7 +842,8 @@ class LinearAdapter(BaseAdapter[Task]):
                     }
                 }
             """)
-            async with self.client as session:
+            client = self._create_client()
+            async with client as session:
                 parent_result = await session.execute(
                     parent_query,
                     variable_values={"identifier": ticket.parent_issue}
@@ -745,7 +875,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 create_query,
                 variable_values={"input": issue_input}
@@ -759,6 +890,11 @@ class LinearAdapter(BaseAdapter[Task]):
 
     async def read(self, ticket_id: str) -> Optional[Task]:
         """Read a Linear issue by identifier with full details."""
+        # Validate credentials before attempting operation
+        is_valid, error_message = self.validate_credentials()
+        if not is_valid:
+            raise ValueError(error_message)
+
         query = gql(ALL_FRAGMENTS + """
             query GetIssue($identifier: String!) {
                 issue(id: $identifier) {
@@ -768,7 +904,8 @@ class LinearAdapter(BaseAdapter[Task]):
         """)
 
         try:
-            async with self.client as session:
+            client = self._create_client()
+            async with client as session:
                 result = await session.execute(
                     query,
                     variable_values={"identifier": ticket_id}
@@ -784,6 +921,11 @@ class LinearAdapter(BaseAdapter[Task]):
 
     async def update(self, ticket_id: str, updates: Dict[str, Any]) -> Optional[Task]:
         """Update a Linear issue with comprehensive field support."""
+        # Validate credentials before attempting operation
+        is_valid, error_message = self.validate_credentials()
+        if not is_valid:
+            raise ValueError(error_message)
+
         # First get the Linear internal ID
         query = gql("""
             query GetIssueId($identifier: String!) {
@@ -793,7 +935,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 query,
                 variable_values={"identifier": ticket_id}
@@ -869,7 +1012,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 update_query,
                 variable_values={"id": linear_id, "input": update_input}
@@ -882,6 +1026,11 @@ class LinearAdapter(BaseAdapter[Task]):
 
     async def delete(self, ticket_id: str) -> bool:
         """Archive (soft delete) a Linear issue."""
+        # Validate credentials before attempting operation
+        is_valid, error_message = self.validate_credentials()
+        if not is_valid:
+            raise ValueError(error_message)
+
         # Get Linear ID
         query = gql("""
             query GetIssueId($identifier: String!) {
@@ -891,7 +1040,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 query,
                 variable_values={"identifier": ticket_id}
@@ -911,7 +1061,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 archive_query,
                 variable_values={"id": linear_id}
@@ -1007,7 +1158,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 query,
                 variable_values={
@@ -1081,7 +1233,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 search_query,
                 variable_values={
@@ -1121,7 +1274,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 query,
                 variable_values={"identifier": comment.ticket_id}
@@ -1153,7 +1307,8 @@ class LinearAdapter(BaseAdapter[Task]):
         if comment.metadata and "parent_comment_id" in comment.metadata:
             comment_input["parentId"] = comment.metadata["parent_comment_id"]
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 create_comment_query,
                 variable_values={"input": comment_input}
@@ -1198,7 +1353,8 @@ class LinearAdapter(BaseAdapter[Task]):
         """)
 
         try:
-            async with self.client as session:
+            client = self._create_client()
+            async with client as session:
                 result = await session.execute(
                     query,
                     variable_values={
@@ -1254,7 +1410,8 @@ class LinearAdapter(BaseAdapter[Task]):
         if description:
             project_input["description"] = description
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 create_query,
                 variable_values={"input": project_input}
@@ -1295,7 +1452,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 query,
                 variable_values={"filter": cycle_filter}
@@ -1330,7 +1488,8 @@ class LinearAdapter(BaseAdapter[Task]):
             }
         """)
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 create_query,
                 variable_values={
@@ -1408,7 +1567,8 @@ class LinearAdapter(BaseAdapter[Task]):
             },
         }
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 create_query,
                 variable_values={"input": attachment_input}
@@ -1507,7 +1667,8 @@ class LinearAdapter(BaseAdapter[Task]):
                 raise ValueError(f"Could not find Linear ID for issue {ticket_id}")
             linear_id = search_result["id"]
 
-        async with self.client as session:
+        client = self._create_client()
+        async with client as session:
             result = await session.execute(
                 update_query,
                 variable_values={
@@ -1554,7 +1715,8 @@ class LinearAdapter(BaseAdapter[Task]):
         """)
 
         try:
-            async with self.client as session:
+            client = self._create_client()
+            async with client as session:
                 result = await session.execute(
                     search_query,
                     variable_values={"identifier": identifier}
@@ -1563,12 +1725,383 @@ class LinearAdapter(BaseAdapter[Task]):
         except:
             return None
 
+    # Epic/Issue/Task Hierarchy Methods (Linear: Project = Epic, Issue = Issue, Sub-issue = Task)
+
+    async def create_epic(
+        self,
+        title: str,
+        description: Optional[str] = None,
+        **kwargs
+    ) -> Optional[Epic]:
+        """Create epic (Linear Project).
+
+        Args:
+            title: Epic/Project name
+            description: Epic/Project description
+            **kwargs: Additional fields (e.g., target_date, lead_id)
+
+        Returns:
+            Created epic or None if failed
+        """
+        team_id = await self._ensure_team_id()
+
+        create_query = gql(PROJECT_FRAGMENT + """
+            mutation CreateProject($input: ProjectCreateInput!) {
+                projectCreate(input: $input) {
+                    success
+                    project {
+                        ...ProjectFields
+                    }
+                }
+            }
+        """)
+
+        project_input = {
+            "name": title,
+            "teamIds": [team_id],
+        }
+        if description:
+            project_input["description"] = description
+
+        # Handle additional Linear-specific fields
+        if "target_date" in kwargs:
+            project_input["targetDate"] = kwargs["target_date"]
+        if "lead_id" in kwargs:
+            project_input["leadId"] = kwargs["lead_id"]
+
+        client = self._create_client()
+        async with client as session:
+            result = await session.execute(
+                create_query,
+                variable_values={"input": project_input}
+            )
+
+        if not result["projectCreate"]["success"]:
+            return None
+
+        project = result["projectCreate"]["project"]
+        return self._epic_from_linear_project(project)
+
+    async def get_epic(self, epic_id: str) -> Optional[Epic]:
+        """Get epic (Linear Project) by ID.
+
+        Args:
+            epic_id: Linear project ID
+
+        Returns:
+            Epic if found, None otherwise
+        """
+        query = gql(PROJECT_FRAGMENT + """
+            query GetProject($id: String!) {
+                project(id: $id) {
+                    ...ProjectFields
+                }
+            }
+        """)
+
+        try:
+            client = self._create_client()
+            async with client as session:
+                result = await session.execute(
+                    query,
+                    variable_values={"id": epic_id}
+                )
+
+            if result.get("project"):
+                return self._epic_from_linear_project(result["project"])
+        except TransportQueryError:
+            pass
+
+        return None
+
+    async def list_epics(self, **kwargs) -> List[Epic]:
+        """List all Linear Projects (Epics).
+
+        Args:
+            **kwargs: Optional filters (team_id, state)
+
+        Returns:
+            List of epics
+        """
+        team_id = await self._ensure_team_id()
+
+        # Build project filter
+        project_filter = {"team": {"id": {"eq": team_id}}}
+
+        if "state" in kwargs:
+            # Map TicketState to Linear project state
+            state_mapping = {
+                TicketState.OPEN: "planned",
+                TicketState.IN_PROGRESS: "started",
+                TicketState.WAITING: "paused",
+                TicketState.DONE: "completed",
+                TicketState.CLOSED: "canceled",
+            }
+            linear_state = state_mapping.get(kwargs["state"], "planned")
+            project_filter["state"] = {"eq": linear_state}
+
+        query = gql(PROJECT_FRAGMENT + """
+            query ListProjects($filter: ProjectFilter, $first: Int!) {
+                projects(filter: $filter, first: $first, orderBy: updatedAt) {
+                    nodes {
+                        ...ProjectFields
+                    }
+                }
+            }
+        """)
+
+        client = self._create_client()
+        async with client as session:
+            result = await session.execute(
+                query,
+                variable_values={
+                    "filter": project_filter,
+                    "first": kwargs.get("limit", 50)
+                }
+            )
+
+        epics = []
+        for project in result["projects"]["nodes"]:
+            epics.append(self._epic_from_linear_project(project))
+
+        return epics
+
+    async def create_issue(
+        self,
+        title: str,
+        description: Optional[str] = None,
+        epic_id: Optional[str] = None,
+        **kwargs
+    ) -> Optional[Task]:
+        """Create issue and optionally associate with project (epic).
+
+        Args:
+            title: Issue title
+            description: Issue description
+            epic_id: Optional Linear project ID (epic)
+            **kwargs: Additional fields
+
+        Returns:
+            Created issue or None if failed
+        """
+        # Use existing create method but ensure it's created as an ISSUE type
+        task = Task(
+            title=title,
+            description=description,
+            ticket_type=TicketType.ISSUE,
+            parent_epic=epic_id,
+            **{k: v for k, v in kwargs.items() if k in Task.__fields__}
+        )
+
+        # The existing create method handles project association via parent_epic field
+        return await self.create(task)
+
+    async def list_issues_by_epic(self, epic_id: str) -> List[Task]:
+        """List all issues in a Linear project (epic).
+
+        Args:
+            epic_id: Linear project ID
+
+        Returns:
+            List of issues belonging to project
+        """
+        query = gql(ISSUE_LIST_FRAGMENTS + """
+            query GetProjectIssues($projectId: String!, $first: Int!) {
+                project(id: $projectId) {
+                    issues(first: $first) {
+                        nodes {
+                            ...IssueCompactFields
+                        }
+                    }
+                }
+            }
+        """)
+
+        try:
+            client = self._create_client()
+            async with client as session:
+                result = await session.execute(
+                    query,
+                    variable_values={"projectId": epic_id, "first": 100}
+                )
+
+            if not result.get("project"):
+                return []
+
+            issues = []
+            for issue_data in result["project"]["issues"]["nodes"]:
+                task = self._task_from_linear_issue(issue_data)
+                # Only return issues (not sub-tasks)
+                if task.is_issue():
+                    issues.append(task)
+
+            return issues
+        except TransportQueryError:
+            return []
+
+    async def create_task(
+        self,
+        title: str,
+        parent_id: str,
+        description: Optional[str] = None,
+        **kwargs
+    ) -> Optional[Task]:
+        """Create task as sub-issue of parent.
+
+        Args:
+            title: Task title
+            parent_id: Required parent issue identifier (e.g., 'BTA-123')
+            description: Task description
+            **kwargs: Additional fields
+
+        Returns:
+            Created task or None if failed
+
+        Raises:
+            ValueError: If parent_id is not provided
+        """
+        if not parent_id:
+            raise ValueError("Tasks must have a parent_id (issue identifier)")
+
+        # Get parent issue's Linear ID
+        parent_query = gql("""
+            query GetIssueId($identifier: String!) {
+                issue(id: $identifier) {
+                    id
+                }
+            }
+        """)
+
+        client = self._create_client()
+        async with client as session:
+            parent_result = await session.execute(
+                parent_query,
+                variable_values={"identifier": parent_id}
+            )
+
+        if not parent_result.get("issue"):
+            raise ValueError(f"Parent issue {parent_id} not found")
+
+        parent_linear_id = parent_result["issue"]["id"]
+
+        # Create task using existing create method
+        task = Task(
+            title=title,
+            description=description,
+            ticket_type=TicketType.TASK,
+            parent_issue=parent_id,
+            **{k: v for k, v in kwargs.items() if k in Task.__fields__}
+        )
+
+        # Validate hierarchy
+        errors = task.validate_hierarchy()
+        if errors:
+            raise ValueError(f"Invalid task hierarchy: {'; '.join(errors)}")
+
+        # Create with parent relationship
+        team_id = await self._ensure_team_id()
+        states = await self._get_workflow_states()
+
+        # Map state to Linear state ID
+        linear_state_type = self._map_state_to_linear(task.state)
+        state_data = states.get(linear_state_type)
+        if not state_data:
+            state_data = states.get("backlog")
+        state_id = state_data["id"] if state_data else None
+
+        # Build issue input (sub-issue)
+        issue_input = {
+            "title": task.title,
+            "teamId": team_id,
+            "parentId": parent_linear_id,  # This makes it a sub-issue
+        }
+
+        if task.description:
+            issue_input["description"] = task.description
+
+        if state_id:
+            issue_input["stateId"] = state_id
+
+        # Set priority
+        if task.priority:
+            issue_input["priority"] = LinearPriorityMapping.TO_LINEAR.get(task.priority, 3)
+
+        # Create sub-issue mutation
+        create_query = gql(ALL_FRAGMENTS + """
+            mutation CreateSubIssue($input: IssueCreateInput!) {
+                issueCreate(input: $input) {
+                    success
+                    issue {
+                        ...IssueFullFields
+                    }
+                }
+            }
+        """)
+
+        client = self._create_client()
+        async with client as session:
+            result = await session.execute(
+                create_query,
+                variable_values={"input": issue_input}
+            )
+
+        if not result["issueCreate"]["success"]:
+            return None
+
+        created_issue = result["issueCreate"]["issue"]
+        return self._task_from_linear_issue(created_issue)
+
+    async def list_tasks_by_issue(self, issue_id: str) -> List[Task]:
+        """List all tasks (sub-issues) under an issue.
+
+        Args:
+            issue_id: Issue identifier (e.g., 'BTA-123')
+
+        Returns:
+            List of tasks belonging to issue
+        """
+        query = gql(ISSUE_LIST_FRAGMENTS + """
+            query GetIssueSubtasks($identifier: String!) {
+                issue(id: $identifier) {
+                    children {
+                        nodes {
+                            ...IssueCompactFields
+                        }
+                    }
+                }
+            }
+        """)
+
+        try:
+            client = self._create_client()
+            async with client as session:
+                result = await session.execute(
+                    query,
+                    variable_values={"identifier": issue_id}
+                )
+
+            if not result.get("issue"):
+                return []
+
+            tasks = []
+            for child_data in result["issue"]["children"]["nodes"]:
+                task = self._task_from_linear_issue(child_data)
+                # Only return tasks (sub-issues)
+                if task.is_task():
+                    tasks.append(task)
+
+            return tasks
+        except TransportQueryError:
+            return []
+
     async def close(self) -> None:
-        """Close the GraphQL client connection."""
-        if hasattr(self.client, 'close_async'):
-            await self.client.close_async()
-        elif hasattr(self.client.transport, 'close'):
-            await self.client.transport.close()
+        """Close the GraphQL client connection.
+
+        Since we create fresh clients for each operation, there's no persistent
+        connection to close. Each client's transport is automatically closed when
+        the async context manager exits.
+        """
+        pass
 
 
 # Register the adapter
