@@ -1,6 +1,6 @@
 """Core models and abstractions for MCP Ticketer."""
 
-from .models import Epic, Task, Comment, TicketState, Priority
+from .models import Epic, Task, Comment, TicketState, Priority, TicketType
 from .adapter import BaseAdapter
 from .registry import AdapterRegistry
 
@@ -10,6 +10,7 @@ __all__ = [
     "Comment",
     "TicketState",
     "Priority",
+    "TicketType",
     "BaseAdapter",
     "AdapterRegistry",
 ]
\ No newline at end of file
